@@ -21,9 +21,11 @@ import sys
 from datetime import datetime
 from typing import Any, Iterator, List, Union
 
+from boto3.resources.base import ResourceMeta
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 
+from .client import CloudWatchClient
 from .literals import (
     AlarmTypeType,
     ComparisonOperatorType,
@@ -60,7 +62,7 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcealarmscollection)
     """
 
@@ -124,7 +126,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcemetricscollection)
     """
 
@@ -169,7 +171,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricalarmscollection)
     """
 
@@ -229,7 +231,7 @@ class MetricAlarmsCollection(ResourceCollection):
 
 class Alarm(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
     """
 
@@ -267,7 +269,7 @@ class Alarm(Boto3ServiceResource):
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdelete-method)
         """
 
@@ -285,7 +287,7 @@ class Alarm(Boto3ServiceResource):
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdescribe_history-method)
         """
 
@@ -293,7 +295,7 @@ class Alarm(Boto3ServiceResource):
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdisable_actions-method)
         """
 
@@ -301,7 +303,7 @@ class Alarm(Boto3ServiceResource):
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmenable_actions-method)
         """
 
@@ -309,7 +311,7 @@ class Alarm(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmget_available_subresources-method)
         """
 
@@ -318,7 +320,7 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmload-method)
         """
 
@@ -327,7 +329,7 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmreload-method)
         """
 
@@ -337,7 +339,7 @@ class Alarm(Boto3ServiceResource):
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmset_state-method)
         """
 
@@ -347,7 +349,7 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
     """
 
@@ -361,7 +363,7 @@ class Metric(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_available_subresources-method)
         """
 
@@ -379,7 +381,7 @@ class Metric(Boto3ServiceResource):
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_statistics-method)
         """
 
@@ -388,7 +390,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricload-method)
         """
 
@@ -420,7 +422,7 @@ class Metric(Boto3ServiceResource):
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_alarm-method)
         """
 
@@ -428,7 +430,7 @@ class Metric(Boto3ServiceResource):
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_data-method)
         """
 
@@ -437,7 +439,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricreload-method)
         """
 
@@ -445,12 +447,17 @@ class Metric(Boto3ServiceResource):
 _Metric = Metric
 
 
+class CloudWatchResourceMeta(ResourceMeta):
+    client: CloudWatchClient
+
+
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
     """
 
+    meta: "CloudWatchResourceMeta"
     alarms: ServiceResourceAlarmsCollection
     metrics: ServiceResourceMetricsCollection
 
@@ -458,7 +465,7 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcealarm-method)
         """
 
@@ -466,7 +473,7 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcemetric-method)
         """
 
@@ -474,6 +481,6 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourceget_available_subresources-method)
         """
